@@ -416,7 +416,7 @@ class SFREAD:
                 elif caltyp == extCalib:
                     diag_ext = self.getparset(rel)['DIAGNAME']
                     diag_ext = ''.join([str_byt.to_str(x) for x in diag_ext])
-                    shot_ext = libddc.previousshot(diag_ext)
+                    shot_ext = libddc.previousshot(diag_ext, shot=self.shot)
                     ext = read_other_sf(shot_ext, diag_ext)
                     return ext.getparset(rel) # same name in external shotfile
         return None
